@@ -70,8 +70,8 @@ pub enum AdminRequestCli {
     ListActiveApps,
     /// Calls AdminRequest::ListApps.
     ListApps(ListApps),
-    ActivateApp(ActivateApp),
-    DeactivateApp(DeactivateApp),
+    EnableApp(EnableApp),
+    DisableApp(DisableApp),
     DumpState(DumpState),
     /// Calls AdminRequest::AddAgentInfo.
     /// [Unimplemented].
@@ -162,18 +162,18 @@ pub struct InstallAppBundle {
 }
 
 #[derive(Debug, StructOpt, Clone)]
-/// Calls AdminRequest::ActivateApp
+/// Calls AdminRequest::EnableApp
 /// and activates the installed app.
-pub struct ActivateApp {
+pub struct EnableApp {
     /// The InstalledAppId to activate.
     pub app_id: String,
 }
 
 #[derive(Debug, StructOpt, Clone)]
-/// Calls AdminRequest::DeactivateApp
-/// and deactivates the installed app.
-pub struct DeactivateApp {
-    /// The InstalledAppId to deactivate.
+/// Calls AdminRequest::DisableApp
+/// and disables the installed app.
+pub struct DisableApp {
+    /// The InstalledAppId to disable.
     pub app_id: String,
 }
 
@@ -234,7 +234,9 @@ pub async fn call(holochain_path: &Path, req: Call) -> anyhow::Result<()> {
                 Ok(cmd) => cmds.push((cmd, None)),
                 Err(e) => {
                     if let holochain_websocket::WebsocketError::Io(e) = &e {
-                        if let std::io::ErrorKind::ConnectionRefused = e.kind() {
+                        if let std::io::ErrorKind::ConnectionRefused
+                        | std::io::ErrorKind::AddrNotAvailable = e.kind()
+                        {
                             let (port, holochain) = run_async(holochain_path, path, None).await?;
                             cmds.push((CmdRunner::new(port).await, Some(holochain)));
                             continue;
@@ -301,21 +303,21 @@ async fn call_inner(cmd: &mut CmdRunner, call: AdminRequestCli) -> anyhow::Resul
             msg!("Cell Ids: {:?}", cells);
         }
         AdminRequestCli::ListActiveApps => {
-            let apps = list_active_apps(cmd).await?;
+            let apps = list_running_apps(cmd).await?;
             msg!("Active Apps: {:?}", apps);
         }
         AdminRequestCli::ListApps(args) => {
             let apps = list_apps(cmd, args).await?;
             msg!("List Apps: {:?}", apps);
         }
-        AdminRequestCli::ActivateApp(args) => {
+        AdminRequestCli::EnableApp(args) => {
             let app_id = args.app_id.clone();
-            activate_app(cmd, args).await?;
+            enable_app(cmd, args).await?;
             msg!("Activated app: {:?}", app_id);
         }
-        AdminRequestCli::DeactivateApp(args) => {
+        AdminRequestCli::DisableApp(args) => {
             let app_id = args.app_id.clone();
-            deactivate_app(cmd, args).await?;
+            disable_app(cmd, args).await?;
             msg!("Deactivated app: {:?}", app_id);
         }
         AdminRequestCli::DumpState(args) => {
@@ -460,9 +462,9 @@ pub async fn install_app(
     let installed_app = cmd.command(r).await?;
     let installed_app =
         expect_match!(installed_app => AdminResponse::AppInstalled, "Failed to install app");
-    activate_app(
+    enable_app(
         cmd,
-        ActivateApp {
+        EnableApp {
             app_id: installed_app.installed_app_id.clone(),
         },
     )
@@ -501,9 +503,9 @@ pub async fn install_app_bundle(
     let installed_app = cmd.command(r).await?;
     let installed_app =
         expect_match!(installed_app => AdminResponse::AppBundleInstalled, "Failed to install app");
-    activate_app(
+    enable_app(
         cmd,
-        ActivateApp {
+        EnableApp {
             app_id: installed_app.installed_app_id.clone(),
         },
     )
@@ -538,7 +540,7 @@ pub async fn list_cell_ids(cmd: &mut CmdRunner) -> anyhow::Result<Vec<CellId>> {
 }
 
 /// Calls [`AdminRequest::ListActiveApps`].
-pub async fn list_active_apps(cmd: &mut CmdRunner) -> anyhow::Result<Vec<String>> {
+pub async fn list_running_apps(cmd: &mut CmdRunner) -> anyhow::Result<Vec<String>> {
     let resp = cmd.command(AdminRequest::ListActiveApps).await?;
     Ok(expect_match!(resp => AdminResponse::ActiveAppsListed, "Failed to list active apps"))
 }
@@ -556,27 +558,27 @@ pub async fn list_apps(
     Ok(expect_match!(resp => AdminResponse::AppsListed, "Failed to list apps"))
 }
 
-/// Calls [`AdminRequest::ActivateApp`] and activates the installed app.
-pub async fn activate_app(cmd: &mut CmdRunner, args: ActivateApp) -> anyhow::Result<()> {
+/// Calls [`AdminRequest::EnableApp`] and activates the installed app.
+pub async fn enable_app(cmd: &mut CmdRunner, args: EnableApp) -> anyhow::Result<()> {
     let resp = cmd
-        .command(AdminRequest::ActivateApp {
+        .command(AdminRequest::EnableApp {
             installed_app_id: args.app_id,
         })
         .await?;
-    expect_match!(resp => AdminResponse::AppActivated, format!("Failed to activate app, got: {:?}", resp));
+    assert!(matches!(resp, AdminResponse::AppEnabled { .. }));
     Ok(())
 }
 
-/// Calls [`AdminRequest::DeactivateApp`] and deactivates the installed app.
-pub async fn deactivate_app(cmd: &mut CmdRunner, args: DeactivateApp) -> anyhow::Result<()> {
+/// Calls [`AdminRequest::DisableApp`] and disables the installed app.
+pub async fn disable_app(cmd: &mut CmdRunner, args: DisableApp) -> anyhow::Result<()> {
     let resp = cmd
-        .command(AdminRequest::DeactivateApp {
+        .command(AdminRequest::DisableApp {
             installed_app_id: args.app_id,
         })
         .await?;
     ensure!(
-        matches!(resp, AdminResponse::AppDeactivated),
-        "Failed to deactivate app, got: {:?}",
+        matches!(resp, AdminResponse::AppDisabled),
+        "Failed to disable app, got: {:?}",
         resp
     );
     Ok(())
@@ -646,8 +648,8 @@ fn parse_dna_hash(arg: &str) -> anyhow::Result<DnaHash> {
 
 fn parse_status_filter(arg: &str) -> anyhow::Result<AppStatusFilter> {
     match arg {
-        "active" => Ok(AppStatusFilter::Active),
-        "inactive" => Ok(AppStatusFilter::Inactive),
+        "active" => Ok(AppStatusFilter::Enabled),
+        "inactive" => Ok(AppStatusFilter::Disabled),
         _ => Err(anyhow::anyhow!(
             "Bad app status filter value: {}, only 'active' and 'inactive' are possible",
             arg
